# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .abstract_call_attribute import AbstractCallAttribute
from .abstract_data_operation_config import AbstractDataOperationConfig
from .abstract_format_attribute import AbstractFormatAttribute
from .abstract_read_attribute import AbstractReadAttribute
from .abstract_write_attribute import AbstractWriteAttribute
from .aggregator_summary import AggregatorSummary
from .attach_data_asset_info import AttachDataAssetInfo
from .attribute import Attribute
from .attribute_profile_result import AttributeProfileResult
from .avro_format_attribute import AvroFormatAttribute
from .base_type import BaseType
from .bicc_read_attributes import BiccReadAttributes
from .bip_call_attribute import BipCallAttribute
from .call_operation_config import CallOperationConfig
from .change_endpoint_compartment_details import ChangeEndpointCompartmentDetails
from .change_registry_compartment_details import ChangeRegistryCompartmentDetails
from .column import Column
from .composite_type import CompositeType
from .compression import Compression
from .config_definition import ConfigDefinition
from .config_parameter_definition import ConfigParameterDefinition
from .config_parameter_value import ConfigParameterValue
from .config_values import ConfigValues
from .configured_type import ConfiguredType
from .connection import Connection
from .connection_property import ConnectionProperty
from .connection_summary import ConnectionSummary
from .connection_summary_collection import ConnectionSummaryCollection
from .connection_validation import ConnectionValidation
from .connection_validation_summary import ConnectionValidationSummary
from .connection_validation_summary_collection import ConnectionValidationSummaryCollection
from .connectivity_validation import ConnectivityValidation
from .connector_attribute import ConnectorAttribute
from .create_attach_data_asset_details import CreateAttachDataAssetDetails
from .create_connection_details import CreateConnectionDetails
from .create_connection_validation_details import CreateConnectionValidationDetails
from .create_connectivity_validation_details import CreateConnectivityValidationDetails
from .create_data_asset_details import CreateDataAssetDetails
from .create_data_preview_details import CreateDataPreviewDetails
from .create_data_profile_details import CreateDataProfileDetails
from .create_de_reference_artifact_details import CreateDeReferenceArtifactDetails
from .create_detach_data_asset_details import CreateDetachDataAssetDetails
from .create_dp_endpoint_details import CreateDpEndpointDetails
from .create_dp_endpoint_from_private import CreateDpEndpointFromPrivate
from .create_dp_endpoint_from_public import CreateDpEndpointFromPublic
from .create_endpoint_details import CreateEndpointDetails
from .create_entity_shape_details import CreateEntityShapeDetails
from .create_entity_shape_from_data_store import CreateEntityShapeFromDataStore
from .create_entity_shape_from_file import CreateEntityShapeFromFile
from .create_entity_shape_from_sql import CreateEntityShapeFromSQL
from .create_entity_shape_from_table import CreateEntityShapeFromTable
from .create_entity_shape_from_view import CreateEntityShapeFromView
from .create_execute_operation_job_details import CreateExecuteOperationJobDetails
from .create_folder_details import CreateFolderDetails
from .create_full_push_down_task_details import CreateFullPushDownTaskDetails
from .create_reference_artifact_details import CreateReferenceArtifactDetails
from .create_registry_details import CreateRegistryDetails
from .create_test_network_connectivity_details import CreateTestNetworkConnectivityDetails
from .csv_format_attribute import CsvFormatAttribute
from .data_asset import DataAsset
from .data_asset_summary import DataAssetSummary
from .data_asset_summary_collection import DataAssetSummaryCollection
from .data_entity import DataEntity
from .data_entity_details import DataEntityDetails
from .data_entity_from_data_store import DataEntityFromDataStore
from .data_entity_from_data_store_entity_details import DataEntityFromDataStoreEntityDetails
from .data_entity_from_file import DataEntityFromFile
from .data_entity_from_file_entity_details import DataEntityFromFileEntityDetails
from .data_entity_from_sql import DataEntityFromSql
from .data_entity_from_sql_entity_details import DataEntityFromSqlEntityDetails
from .data_entity_from_table import DataEntityFromTable
from .data_entity_from_table_entity_details import DataEntityFromTableEntityDetails
from .data_entity_from_view import DataEntityFromView
from .data_entity_from_view_entity_details import DataEntityFromViewEntityDetails
from .data_entity_summary import DataEntitySummary
from .data_entity_summary_collection import DataEntitySummaryCollection
from .data_entity_summary_from_data_store import DataEntitySummaryFromDataStore
from .data_entity_summary_from_file import DataEntitySummaryFromFile
from .data_entity_summary_from_sql import DataEntitySummaryFromSql
from .data_entity_summary_from_table import DataEntitySummaryFromTable
from .data_entity_summary_from_view import DataEntitySummaryFromView
from .data_format import DataFormat
from .data_preview import DataPreview
from .data_profile import DataProfile
from .data_type import DataType
from .data_type_stat import DataTypeStat
from .date_attribute import DateAttribute
from .de_reference_info import DeReferenceInfo
from .derived_type import DerivedType
from .detach_data_asset_info import DetachDataAssetInfo
from .dp_endpoint import DpEndpoint
from .dp_endpoint_details import DpEndpointDetails
from .dp_endpoint_from_private import DpEndpointFromPrivate
from .dp_endpoint_from_private_details import DpEndpointFromPrivateDetails
from .dp_endpoint_from_public import DpEndpointFromPublic
from .dp_endpoint_from_public_details import DpEndpointFromPublicDetails
from .dp_endpoint_summary import DpEndpointSummary
from .dp_endpoint_summary_from_private import DpEndpointSummaryFromPrivate
from .dp_endpoint_summary_from_public import DpEndpointSummaryFromPublic
from .endpoint import Endpoint
from .endpoint_summary import EndpointSummary
from .endpoint_summary_collection import EndpointSummaryCollection
from .entity_profile_result import EntityProfileResult
from .entity_shape import EntityShape
from .entity_shape_from_data_store import EntityShapeFromDataStore
from .entity_shape_from_file import EntityShapeFromFile
from .entity_shape_from_sql import EntityShapeFromSQL
from .entity_shape_from_table import EntityShapeFromTable
from .entity_shape_from_view import EntityShapeFromView
from .error_details import ErrorDetails
from .execute_operation_job import ExecuteOperationJob
from .execute_operation_job_details import ExecuteOperationJobDetails
from .external_storage import ExternalStorage
from .filter_push import FilterPush
from .folder import Folder
from .folder_summary import FolderSummary
from .folder_summary_collection import FolderSummaryCollection
from .foreign_key import ForeignKey
from .full_push_down_task_response import FullPushDownTaskResponse
from .hdfs_write_attributes import HdfsWriteAttributes
from .histogram import Histogram
from .input_port import InputPort
from .join import Join
from .json_format_attribute import JsonFormatAttribute
from .key import Key
from .key_attribute import KeyAttribute
from .key_range import KeyRange
from .key_range_partition_config import KeyRangePartitionConfig
from .message import Message
from .native_shape_field import NativeShapeField
from .network_connectivity_status import NetworkConnectivityStatus
from .network_connectivity_status_collection import NetworkConnectivityStatusCollection
from .numeric_attribute import NumericAttribute
from .object_freq_stat import ObjectFreqStat
from .object_metadata import ObjectMetadata
from .object_storage_write_attributes import ObjectStorageWriteAttributes
from .operation import Operation
from .operation_exec_result import OperationExecResult
from .operation_from_procedure import OperationFromProcedure
from .operation_input_record import OperationInputRecord
from .operation_summary import OperationSummary
from .operation_summary_collection import OperationSummaryCollection
from .operation_summary_from_procedure import OperationSummaryFromProcedure
from .oracle_adwc_write_attributes import OracleAdwcWriteAttributes
from .oracle_atp_write_attributes import OracleAtpWriteAttributes
from .oracle_read_attribute import OracleReadAttribute
from .oracle_read_attributes import OracleReadAttributes
from .oracle_write_attributes import OracleWriteAttributes
from .outlier import Outlier
from .output_port import OutputPort
from .parameter import Parameter
from .parent_reference import ParentReference
from .parquet_format_attribute import ParquetFormatAttribute
from .partition_config import PartitionConfig
from .primary_key import PrimaryKey
from .profile_config import ProfileConfig
from .profile_stat import ProfileStat
from .push_down_operation import PushDownOperation
from .query import Query
from .read_operation_config import ReadOperationConfig
from .reference_artifact_summary import ReferenceArtifactSummary
from .reference_artifact_summary_collection import ReferenceArtifactSummaryCollection
from .reference_info import ReferenceInfo
from .registry import Registry
from .registry_metadata import RegistryMetadata
from .registry_summary import RegistrySummary
from .registry_summary_collection import RegistrySummaryCollection
from .row import Row
from .schema import Schema
from .schema_drift_config import SchemaDriftConfig
from .schema_summary import SchemaSummary
from .schema_summary_collection import SchemaSummaryCollection
from .select import Select
from .shape import Shape
from .shape_field import ShapeField
from .sort import Sort
from .sort_clause import SortClause
from .source import Source
from .string_attribute import StringAttribute
from .structured_type import StructuredType
from .target import Target
from .test_network_connectivity import TestNetworkConnectivity
from .type import Type
from .type_library import TypeLibrary
from .type_summary import TypeSummary
from .type_system import TypeSystem
from .typed_object import TypedObject
from .types_summary_collection import TypesSummaryCollection
from .unique_key import UniqueKey
from .update_connection_details import UpdateConnectionDetails
from .update_data_asset_details import UpdateDataAssetDetails
from .update_dp_endpoint_details import UpdateDpEndpointDetails
from .update_dp_endpoint_from_private import UpdateDpEndpointFromPrivate
from .update_dp_endpoint_from_public import UpdateDpEndpointFromPublic
from .update_endpoint_details import UpdateEndpointDetails
from .update_folder_details import UpdateFolderDetails
from .update_registry_details import UpdateRegistryDetails
from .validation_message import ValidationMessage
from .validation_result import ValidationResult
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_error_summary import WorkRequestErrorSummary
from .work_request_log import WorkRequestLog
from .work_request_log_collection import WorkRequestLogCollection
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary
from .work_request_summary_collection import WorkRequestSummaryCollection
from .write_operation_config import WriteOperationConfig

# Maps type names to classes for data_connectivity services.
data_connectivity_type_mapping = {
    "AbstractCallAttribute": AbstractCallAttribute,
    "AbstractDataOperationConfig": AbstractDataOperationConfig,
    "AbstractFormatAttribute": AbstractFormatAttribute,
    "AbstractReadAttribute": AbstractReadAttribute,
    "AbstractWriteAttribute": AbstractWriteAttribute,
    "AggregatorSummary": AggregatorSummary,
    "AttachDataAssetInfo": AttachDataAssetInfo,
    "Attribute": Attribute,
    "AttributeProfileResult": AttributeProfileResult,
    "AvroFormatAttribute": AvroFormatAttribute,
    "BaseType": BaseType,
    "BiccReadAttributes": BiccReadAttributes,
    "BipCallAttribute": BipCallAttribute,
    "CallOperationConfig": CallOperationConfig,
    "ChangeEndpointCompartmentDetails": ChangeEndpointCompartmentDetails,
    "ChangeRegistryCompartmentDetails": ChangeRegistryCompartmentDetails,
    "Column": Column,
    "CompositeType": CompositeType,
    "Compression": Compression,
    "ConfigDefinition": ConfigDefinition,
    "ConfigParameterDefinition": ConfigParameterDefinition,
    "ConfigParameterValue": ConfigParameterValue,
    "ConfigValues": ConfigValues,
    "ConfiguredType": ConfiguredType,
    "Connection": Connection,
    "ConnectionProperty": ConnectionProperty,
    "ConnectionSummary": ConnectionSummary,
    "ConnectionSummaryCollection": ConnectionSummaryCollection,
    "ConnectionValidation": ConnectionValidation,
    "ConnectionValidationSummary": ConnectionValidationSummary,
    "ConnectionValidationSummaryCollection": ConnectionValidationSummaryCollection,
    "ConnectivityValidation": ConnectivityValidation,
    "ConnectorAttribute": ConnectorAttribute,
    "CreateAttachDataAssetDetails": CreateAttachDataAssetDetails,
    "CreateConnectionDetails": CreateConnectionDetails,
    "CreateConnectionValidationDetails": CreateConnectionValidationDetails,
    "CreateConnectivityValidationDetails": CreateConnectivityValidationDetails,
    "CreateDataAssetDetails": CreateDataAssetDetails,
    "CreateDataPreviewDetails": CreateDataPreviewDetails,
    "CreateDataProfileDetails": CreateDataProfileDetails,
    "CreateDeReferenceArtifactDetails": CreateDeReferenceArtifactDetails,
    "CreateDetachDataAssetDetails": CreateDetachDataAssetDetails,
    "CreateDpEndpointDetails": CreateDpEndpointDetails,
    "CreateDpEndpointFromPrivate": CreateDpEndpointFromPrivate,
    "CreateDpEndpointFromPublic": CreateDpEndpointFromPublic,
    "CreateEndpointDetails": CreateEndpointDetails,
    "CreateEntityShapeDetails": CreateEntityShapeDetails,
    "CreateEntityShapeFromDataStore": CreateEntityShapeFromDataStore,
    "CreateEntityShapeFromFile": CreateEntityShapeFromFile,
    "CreateEntityShapeFromSQL": CreateEntityShapeFromSQL,
    "CreateEntityShapeFromTable": CreateEntityShapeFromTable,
    "CreateEntityShapeFromView": CreateEntityShapeFromView,
    "CreateExecuteOperationJobDetails": CreateExecuteOperationJobDetails,
    "CreateFolderDetails": CreateFolderDetails,
    "CreateFullPushDownTaskDetails": CreateFullPushDownTaskDetails,
    "CreateReferenceArtifactDetails": CreateReferenceArtifactDetails,
    "CreateRegistryDetails": CreateRegistryDetails,
    "CreateTestNetworkConnectivityDetails": CreateTestNetworkConnectivityDetails,
    "CsvFormatAttribute": CsvFormatAttribute,
    "DataAsset": DataAsset,
    "DataAssetSummary": DataAssetSummary,
    "DataAssetSummaryCollection": DataAssetSummaryCollection,
    "DataEntity": DataEntity,
    "DataEntityDetails": DataEntityDetails,
    "DataEntityFromDataStore": DataEntityFromDataStore,
    "DataEntityFromDataStoreEntityDetails": DataEntityFromDataStoreEntityDetails,
    "DataEntityFromFile": DataEntityFromFile,
    "DataEntityFromFileEntityDetails": DataEntityFromFileEntityDetails,
    "DataEntityFromSql": DataEntityFromSql,
    "DataEntityFromSqlEntityDetails": DataEntityFromSqlEntityDetails,
    "DataEntityFromTable": DataEntityFromTable,
    "DataEntityFromTableEntityDetails": DataEntityFromTableEntityDetails,
    "DataEntityFromView": DataEntityFromView,
    "DataEntityFromViewEntityDetails": DataEntityFromViewEntityDetails,
    "DataEntitySummary": DataEntitySummary,
    "DataEntitySummaryCollection": DataEntitySummaryCollection,
    "DataEntitySummaryFromDataStore": DataEntitySummaryFromDataStore,
    "DataEntitySummaryFromFile": DataEntitySummaryFromFile,
    "DataEntitySummaryFromSql": DataEntitySummaryFromSql,
    "DataEntitySummaryFromTable": DataEntitySummaryFromTable,
    "DataEntitySummaryFromView": DataEntitySummaryFromView,
    "DataFormat": DataFormat,
    "DataPreview": DataPreview,
    "DataProfile": DataProfile,
    "DataType": DataType,
    "DataTypeStat": DataTypeStat,
    "DateAttribute": DateAttribute,
    "DeReferenceInfo": DeReferenceInfo,
    "DerivedType": DerivedType,
    "DetachDataAssetInfo": DetachDataAssetInfo,
    "DpEndpoint": DpEndpoint,
    "DpEndpointDetails": DpEndpointDetails,
    "DpEndpointFromPrivate": DpEndpointFromPrivate,
    "DpEndpointFromPrivateDetails": DpEndpointFromPrivateDetails,
    "DpEndpointFromPublic": DpEndpointFromPublic,
    "DpEndpointFromPublicDetails": DpEndpointFromPublicDetails,
    "DpEndpointSummary": DpEndpointSummary,
    "DpEndpointSummaryFromPrivate": DpEndpointSummaryFromPrivate,
    "DpEndpointSummaryFromPublic": DpEndpointSummaryFromPublic,
    "Endpoint": Endpoint,
    "EndpointSummary": EndpointSummary,
    "EndpointSummaryCollection": EndpointSummaryCollection,
    "EntityProfileResult": EntityProfileResult,
    "EntityShape": EntityShape,
    "EntityShapeFromDataStore": EntityShapeFromDataStore,
    "EntityShapeFromFile": EntityShapeFromFile,
    "EntityShapeFromSQL": EntityShapeFromSQL,
    "EntityShapeFromTable": EntityShapeFromTable,
    "EntityShapeFromView": EntityShapeFromView,
    "ErrorDetails": ErrorDetails,
    "ExecuteOperationJob": ExecuteOperationJob,
    "ExecuteOperationJobDetails": ExecuteOperationJobDetails,
    "ExternalStorage": ExternalStorage,
    "FilterPush": FilterPush,
    "Folder": Folder,
    "FolderSummary": FolderSummary,
    "FolderSummaryCollection": FolderSummaryCollection,
    "ForeignKey": ForeignKey,
    "FullPushDownTaskResponse": FullPushDownTaskResponse,
    "HdfsWriteAttributes": HdfsWriteAttributes,
    "Histogram": Histogram,
    "InputPort": InputPort,
    "Join": Join,
    "JsonFormatAttribute": JsonFormatAttribute,
    "Key": Key,
    "KeyAttribute": KeyAttribute,
    "KeyRange": KeyRange,
    "KeyRangePartitionConfig": KeyRangePartitionConfig,
    "Message": Message,
    "NativeShapeField": NativeShapeField,
    "NetworkConnectivityStatus": NetworkConnectivityStatus,
    "NetworkConnectivityStatusCollection": NetworkConnectivityStatusCollection,
    "NumericAttribute": NumericAttribute,
    "ObjectFreqStat": ObjectFreqStat,
    "ObjectMetadata": ObjectMetadata,
    "ObjectStorageWriteAttributes": ObjectStorageWriteAttributes,
    "Operation": Operation,
    "OperationExecResult": OperationExecResult,
    "OperationFromProcedure": OperationFromProcedure,
    "OperationInputRecord": OperationInputRecord,
    "OperationSummary": OperationSummary,
    "OperationSummaryCollection": OperationSummaryCollection,
    "OperationSummaryFromProcedure": OperationSummaryFromProcedure,
    "OracleAdwcWriteAttributes": OracleAdwcWriteAttributes,
    "OracleAtpWriteAttributes": OracleAtpWriteAttributes,
    "OracleReadAttribute": OracleReadAttribute,
    "OracleReadAttributes": OracleReadAttributes,
    "OracleWriteAttributes": OracleWriteAttributes,
    "Outlier": Outlier,
    "OutputPort": OutputPort,
    "Parameter": Parameter,
    "ParentReference": ParentReference,
    "ParquetFormatAttribute": ParquetFormatAttribute,
    "PartitionConfig": PartitionConfig,
    "PrimaryKey": PrimaryKey,
    "ProfileConfig": ProfileConfig,
    "ProfileStat": ProfileStat,
    "PushDownOperation": PushDownOperation,
    "Query": Query,
    "ReadOperationConfig": ReadOperationConfig,
    "ReferenceArtifactSummary": ReferenceArtifactSummary,
    "ReferenceArtifactSummaryCollection": ReferenceArtifactSummaryCollection,
    "ReferenceInfo": ReferenceInfo,
    "Registry": Registry,
    "RegistryMetadata": RegistryMetadata,
    "RegistrySummary": RegistrySummary,
    "RegistrySummaryCollection": RegistrySummaryCollection,
    "Row": Row,
    "Schema": Schema,
    "SchemaDriftConfig": SchemaDriftConfig,
    "SchemaSummary": SchemaSummary,
    "SchemaSummaryCollection": SchemaSummaryCollection,
    "Select": Select,
    "Shape": Shape,
    "ShapeField": ShapeField,
    "Sort": Sort,
    "SortClause": SortClause,
    "Source": Source,
    "StringAttribute": StringAttribute,
    "StructuredType": StructuredType,
    "Target": Target,
    "TestNetworkConnectivity": TestNetworkConnectivity,
    "Type": Type,
    "TypeLibrary": TypeLibrary,
    "TypeSummary": TypeSummary,
    "TypeSystem": TypeSystem,
    "TypedObject": TypedObject,
    "TypesSummaryCollection": TypesSummaryCollection,
    "UniqueKey": UniqueKey,
    "UpdateConnectionDetails": UpdateConnectionDetails,
    "UpdateDataAssetDetails": UpdateDataAssetDetails,
    "UpdateDpEndpointDetails": UpdateDpEndpointDetails,
    "UpdateDpEndpointFromPrivate": UpdateDpEndpointFromPrivate,
    "UpdateDpEndpointFromPublic": UpdateDpEndpointFromPublic,
    "UpdateEndpointDetails": UpdateEndpointDetails,
    "UpdateFolderDetails": UpdateFolderDetails,
    "UpdateRegistryDetails": UpdateRegistryDetails,
    "ValidationMessage": ValidationMessage,
    "ValidationResult": ValidationResult,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestErrorSummary": WorkRequestErrorSummary,
    "WorkRequestLog": WorkRequestLog,
    "WorkRequestLogCollection": WorkRequestLogCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary,
    "WorkRequestSummaryCollection": WorkRequestSummaryCollection,
    "WriteOperationConfig": WriteOperationConfig
}



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ParentReference(object):
    """
    A reference to the object's parent.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ParentReference object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param parent:
            The value to assign to the parent property of this ParentReference.
        :type parent: str

        :param root_doc_id:
            The value to assign to the root_doc_id property of this ParentReference.
        :type root_doc_id: str

        """
        self.swagger_types = {
            'parent': 'str',
            'root_doc_id': 'str'
        }

        self.attribute_map = {
            'parent': 'parent',
            'root_doc_id': 'rootDocId'
        }

        self._parent = None
        self._root_doc_id = None

    @property
    def parent(self):
        """
        Gets the parent of this ParentReference.
        Key of the parent object.


        :return: The parent of this ParentReference.
        :rtype: str
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """
        Sets the parent of this ParentReference.
        Key of the parent object.


        :param parent: The parent of this ParentReference.
        :type: str
        """
        self._parent = parent

    @property
    def root_doc_id(self):
        """
        Gets the root_doc_id of this ParentReference.
        Key of the root document object.


        :return: The root_doc_id of this ParentReference.
        :rtype: str
        """
        return self._root_doc_id

    @root_doc_id.setter
    def root_doc_id(self, root_doc_id):
        """
        Sets the root_doc_id of this ParentReference.
        Key of the root document object.


        :param root_doc_id: The root_doc_id of this ParentReference.
        :type: str
        """
        self._root_doc_id = root_doc_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .exadata_insight_resource_statistics_aggregation import ExadataInsightResourceStatisticsAggregation
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ExadataDiskgroupStatisticsSummary(ExadataInsightResourceStatisticsAggregation):
    """
    Diskgroup details and statistics.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ExadataDiskgroupStatisticsSummary object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.ExadataDiskgroupStatisticsSummary.exadata_resource_type` attribute
        of this class is ``DISKGROUP`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param exadata_resource_type:
            The value to assign to the exadata_resource_type property of this ExadataDiskgroupStatisticsSummary.
            Allowed values for this property are: "DATABASE", "HOST", "STORAGE_SERVER", "DISKGROUP"
        :type exadata_resource_type: str

        :param resource_details:
            The value to assign to the resource_details property of this ExadataDiskgroupStatisticsSummary.
        :type resource_details: oci.opsi.models.DiskGroupDetails

        :param current_statistics:
            The value to assign to the current_statistics property of this ExadataDiskgroupStatisticsSummary.
        :type current_statistics: oci.opsi.models.ExadataInsightResourceStatistics

        """
        self.swagger_types = {
            'exadata_resource_type': 'str',
            'resource_details': 'DiskGroupDetails',
            'current_statistics': 'ExadataInsightResourceStatistics'
        }

        self.attribute_map = {
            'exadata_resource_type': 'exadataResourceType',
            'resource_details': 'resourceDetails',
            'current_statistics': 'currentStatistics'
        }

        self._exadata_resource_type = None
        self._resource_details = None
        self._current_statistics = None
        self._exadata_resource_type = 'DISKGROUP'

    @property
    def resource_details(self):
        """
        **[Required]** Gets the resource_details of this ExadataDiskgroupStatisticsSummary.

        :return: The resource_details of this ExadataDiskgroupStatisticsSummary.
        :rtype: oci.opsi.models.DiskGroupDetails
        """
        return self._resource_details

    @resource_details.setter
    def resource_details(self, resource_details):
        """
        Sets the resource_details of this ExadataDiskgroupStatisticsSummary.

        :param resource_details: The resource_details of this ExadataDiskgroupStatisticsSummary.
        :type: oci.opsi.models.DiskGroupDetails
        """
        self._resource_details = resource_details

    @property
    def current_statistics(self):
        """
        **[Required]** Gets the current_statistics of this ExadataDiskgroupStatisticsSummary.

        :return: The current_statistics of this ExadataDiskgroupStatisticsSummary.
        :rtype: oci.opsi.models.ExadataInsightResourceStatistics
        """
        return self._current_statistics

    @current_statistics.setter
    def current_statistics(self, current_statistics):
        """
        Sets the current_statistics of this ExadataDiskgroupStatisticsSummary.

        :param current_statistics: The current_statistics of this ExadataDiskgroupStatisticsSummary.
        :type: oci.opsi.models.ExadataInsightResourceStatistics
        """
        self._current_statistics = current_statistics

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResourceRiskScoreAggregationCollection(object):
    """
    Collection of Resource risk scores
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ResourceRiskScoreAggregationCollection object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param filter_type:
            The value to assign to the filter_type property of this ResourceRiskScoreAggregationCollection.
        :type filter_type: str

        :param filter_id:
            The value to assign to the filter_id property of this ResourceRiskScoreAggregationCollection.
        :type filter_id: str

        :param risk_threshold:
            The value to assign to the risk_threshold property of this ResourceRiskScoreAggregationCollection.
        :type risk_threshold: int

        :param items:
            The value to assign to the items property of this ResourceRiskScoreAggregationCollection.
        :type items: list[oci.cloud_guard.models.ResourceRiskScoreAggregation]

        """
        self.swagger_types = {
            'filter_type': 'str',
            'filter_id': 'str',
            'risk_threshold': 'int',
            'items': 'list[ResourceRiskScoreAggregation]'
        }

        self.attribute_map = {
            'filter_type': 'filterType',
            'filter_id': 'filterId',
            'risk_threshold': 'riskThreshold',
            'items': 'items'
        }

        self._filter_type = None
        self._filter_id = None
        self._risk_threshold = None
        self._items = None

    @property
    def filter_type(self):
        """
        **[Required]** Gets the filter_type of this ResourceRiskScoreAggregationCollection.
        Type of filter. Valid Values - problem_id and resource_id


        :return: The filter_type of this ResourceRiskScoreAggregationCollection.
        :rtype: str
        """
        return self._filter_type

    @filter_type.setter
    def filter_type(self, filter_type):
        """
        Sets the filter_type of this ResourceRiskScoreAggregationCollection.
        Type of filter. Valid Values - problem_id and resource_id


        :param filter_type: The filter_type of this ResourceRiskScoreAggregationCollection.
        :type: str
        """
        self._filter_type = filter_type

    @property
    def filter_id(self):
        """
        **[Required]** Gets the filter_id of this ResourceRiskScoreAggregationCollection.
        Id value on which risk scores are filtered


        :return: The filter_id of this ResourceRiskScoreAggregationCollection.
        :rtype: str
        """
        return self._filter_id

    @filter_id.setter
    def filter_id(self, filter_id):
        """
        Sets the filter_id of this ResourceRiskScoreAggregationCollection.
        Id value on which risk scores are filtered


        :param filter_id: The filter_id of this ResourceRiskScoreAggregationCollection.
        :type: str
        """
        self._filter_id = filter_id

    @property
    def risk_threshold(self):
        """
        Gets the risk_threshold of this ResourceRiskScoreAggregationCollection.
        Risk Score


        :return: The risk_threshold of this ResourceRiskScoreAggregationCollection.
        :rtype: int
        """
        return self._risk_threshold

    @risk_threshold.setter
    def risk_threshold(self, risk_threshold):
        """
        Sets the risk_threshold of this ResourceRiskScoreAggregationCollection.
        Risk Score


        :param risk_threshold: The risk_threshold of this ResourceRiskScoreAggregationCollection.
        :type: int
        """
        self._risk_threshold = risk_threshold

    @property
    def items(self):
        """
        **[Required]** Gets the items of this ResourceRiskScoreAggregationCollection.
        List of ResourceRiskScoreAggregation


        :return: The items of this ResourceRiskScoreAggregationCollection.
        :rtype: list[oci.cloud_guard.models.ResourceRiskScoreAggregation]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this ResourceRiskScoreAggregationCollection.
        List of ResourceRiskScoreAggregation


        :param items: The items of this ResourceRiskScoreAggregationCollection.
        :type: list[oci.cloud_guard.models.ResourceRiskScoreAggregation]
        """
        self._items = items

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TriggerSchedule(object):
    """
    Specifies a trigger schedule. Timing information for when to initiate automated syncs.
    """

    #: A constant which can be used with the schedule_type property of a TriggerSchedule.
    #: This constant has a value of "NONE"
    SCHEDULE_TYPE_NONE = "NONE"

    #: A constant which can be used with the schedule_type property of a TriggerSchedule.
    #: This constant has a value of "DEFAULT"
    SCHEDULE_TYPE_DEFAULT = "DEFAULT"

    #: A constant which can be used with the schedule_type property of a TriggerSchedule.
    #: This constant has a value of "CUSTOM"
    SCHEDULE_TYPE_CUSTOM = "CUSTOM"

    def __init__(self, **kwargs):
        """
        Initializes a new TriggerSchedule object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param schedule_type:
            The value to assign to the schedule_type property of this TriggerSchedule.
            Allowed values for this property are: "NONE", "DEFAULT", "CUSTOM", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type schedule_type: str

        :param custom_schedule:
            The value to assign to the custom_schedule property of this TriggerSchedule.
        :type custom_schedule: str

        """
        self.swagger_types = {
            'schedule_type': 'str',
            'custom_schedule': 'str'
        }

        self.attribute_map = {
            'schedule_type': 'scheduleType',
            'custom_schedule': 'customSchedule'
        }

        self._schedule_type = None
        self._custom_schedule = None

    @property
    def schedule_type(self):
        """
        **[Required]** Gets the schedule_type of this TriggerSchedule.
        Different types of trigger schedule:
        NONE - No automated synchronization schedule.
        DEFAULT - Trigger schedule is every 30 minutes.
        CUSTOM - Custom triggering schedule.

        Allowed values for this property are: "NONE", "DEFAULT", "CUSTOM", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The schedule_type of this TriggerSchedule.
        :rtype: str
        """
        return self._schedule_type

    @schedule_type.setter
    def schedule_type(self, schedule_type):
        """
        Sets the schedule_type of this TriggerSchedule.
        Different types of trigger schedule:
        NONE - No automated synchronization schedule.
        DEFAULT - Trigger schedule is every 30 minutes.
        CUSTOM - Custom triggering schedule.


        :param schedule_type: The schedule_type of this TriggerSchedule.
        :type: str
        """
        allowed_values = ["NONE", "DEFAULT", "CUSTOM"]
        if not value_allowed_none_or_none_sentinel(schedule_type, allowed_values):
            schedule_type = 'UNKNOWN_ENUM_VALUE'
        self._schedule_type = schedule_type

    @property
    def custom_schedule(self):
        """
        Gets the custom_schedule of this TriggerSchedule.
        Valid if type is CUSTOM. Following RFC 5545 recurrence rules, we can specify starting time, occurrence frequency, and interval size.
        Example for frequency could be DAILY/WEEKLY/HOURLY or any RFC 5545 supported frequency, which is followed by start time of this window.
        You can control the start time with BYHOUR, BYMINUTE and BYSECONDS. It is followed by the interval size.


        :return: The custom_schedule of this TriggerSchedule.
        :rtype: str
        """
        return self._custom_schedule

    @custom_schedule.setter
    def custom_schedule(self, custom_schedule):
        """
        Sets the custom_schedule of this TriggerSchedule.
        Valid if type is CUSTOM. Following RFC 5545 recurrence rules, we can specify starting time, occurrence frequency, and interval size.
        Example for frequency could be DAILY/WEEKLY/HOURLY or any RFC 5545 supported frequency, which is followed by start time of this window.
        You can control the start time with BYHOUR, BYMINUTE and BYSECONDS. It is followed by the interval size.


        :param custom_schedule: The custom_schedule of this TriggerSchedule.
        :type: str
        """
        self._custom_schedule = custom_schedule

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BulkUploadValidationErrorInfo(object):
    """
    Detailed error information corresponding to each column for a particular supported license record that could not be uploaded.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new BulkUploadValidationErrorInfo object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param row_number:
            The value to assign to the row_number property of this BulkUploadValidationErrorInfo.
        :type row_number: int

        :param product_name:
            The value to assign to the product_name property of this BulkUploadValidationErrorInfo.
        :type product_name: str

        :param row_error:
            The value to assign to the row_error property of this BulkUploadValidationErrorInfo.
        :type row_error: list[oci.license_manager.models.BulkUploadCellInfo]

        """
        self.swagger_types = {
            'row_number': 'int',
            'product_name': 'str',
            'row_error': 'list[BulkUploadCellInfo]'
        }

        self.attribute_map = {
            'row_number': 'rowNumber',
            'product_name': 'productName',
            'row_error': 'rowError'
        }

        self._row_number = None
        self._product_name = None
        self._row_error = None

    @property
    def row_number(self):
        """
        **[Required]** Gets the row_number of this BulkUploadValidationErrorInfo.
        Refers to the license record number as provided in the bulk upload file.


        :return: The row_number of this BulkUploadValidationErrorInfo.
        :rtype: int
        """
        return self._row_number

    @row_number.setter
    def row_number(self, row_number):
        """
        Sets the row_number of this BulkUploadValidationErrorInfo.
        Refers to the license record number as provided in the bulk upload file.


        :param row_number: The row_number of this BulkUploadValidationErrorInfo.
        :type: int
        """
        self._row_number = row_number

    @property
    def product_name(self):
        """
        **[Required]** Gets the product_name of this BulkUploadValidationErrorInfo.
        Product name of invalid row.


        :return: The product_name of this BulkUploadValidationErrorInfo.
        :rtype: str
        """
        return self._product_name

    @product_name.setter
    def product_name(self, product_name):
        """
        Sets the product_name of this BulkUploadValidationErrorInfo.
        Product name of invalid row.


        :param product_name: The product_name of this BulkUploadValidationErrorInfo.
        :type: str
        """
        self._product_name = product_name

    @property
    def row_error(self):
        """
        **[Required]** Gets the row_error of this BulkUploadValidationErrorInfo.
        Error information corresponding to each column.


        :return: The row_error of this BulkUploadValidationErrorInfo.
        :rtype: list[oci.license_manager.models.BulkUploadCellInfo]
        """
        return self._row_error

    @row_error.setter
    def row_error(self, row_error):
        """
        Sets the row_error of this BulkUploadValidationErrorInfo.
        Error information corresponding to each column.


        :param row_error: The row_error of this BulkUploadValidationErrorInfo.
        :type: list[oci.license_manager.models.BulkUploadCellInfo]
        """
        self._row_error = row_error

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Project(object):
    """
    The project type contains the audit summary information and the definition of the project.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Project object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this Project.
        :type key: str

        :param model_type:
            The value to assign to the model_type property of this Project.
        :type model_type: str

        :param model_version:
            The value to assign to the model_version property of this Project.
        :type model_version: str

        :param name:
            The value to assign to the name property of this Project.
        :type name: str

        :param description:
            The value to assign to the description property of this Project.
        :type description: str

        :param object_status:
            The value to assign to the object_status property of this Project.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this Project.
        :type identifier: str

        :param object_version:
            The value to assign to the object_version property of this Project.
        :type object_version: int

        :param parent_ref:
            The value to assign to the parent_ref property of this Project.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param metadata:
            The value to assign to the metadata property of this Project.
        :type metadata: oci.data_integration.models.ObjectMetadata

        :param key_map:
            The value to assign to the key_map property of this Project.
        :type key_map: dict(str, str)

        """
        self.swagger_types = {
            'key': 'str',
            'model_type': 'str',
            'model_version': 'str',
            'name': 'str',
            'description': 'str',
            'object_status': 'int',
            'identifier': 'str',
            'object_version': 'int',
            'parent_ref': 'ParentReference',
            'metadata': 'ObjectMetadata',
            'key_map': 'dict(str, str)'
        }

        self.attribute_map = {
            'key': 'key',
            'model_type': 'modelType',
            'model_version': 'modelVersion',
            'name': 'name',
            'description': 'description',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'object_version': 'objectVersion',
            'parent_ref': 'parentRef',
            'metadata': 'metadata',
            'key_map': 'keyMap'
        }

        self._key = None
        self._model_type = None
        self._model_version = None
        self._name = None
        self._description = None
        self._object_status = None
        self._identifier = None
        self._object_version = None
        self._parent_ref = None
        self._metadata = None
        self._key_map = None

    @property
    def key(self):
        """
        Gets the key of this Project.
        Generated key that can be used in API calls to identify project.


        :return: The key of this Project.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this Project.
        Generated key that can be used in API calls to identify project.


        :param key: The key of this Project.
        :type: str
        """
        self._key = key

    @property
    def model_type(self):
        """
        Gets the model_type of this Project.
        The type of the object.


        :return: The model_type of this Project.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this Project.
        The type of the object.


        :param model_type: The model_type of this Project.
        :type: str
        """
        self._model_type = model_type

    @property
    def model_version(self):
        """
        Gets the model_version of this Project.
        The model version of an object.


        :return: The model_version of this Project.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this Project.
        The model version of an object.


        :param model_version: The model_version of this Project.
        :type: str
        """
        self._model_version = model_version

    @property
    def name(self):
        """
        Gets the name of this Project.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this Project.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Project.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this Project.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this Project.
        A user defined description for the project.


        :return: The description of this Project.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Project.
        A user defined description for the project.


        :param description: The description of this Project.
        :type: str
        """
        self._description = description

    @property
    def object_status(self):
        """
        Gets the object_status of this Project.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this Project.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this Project.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this Project.
        :type: int
        """
        self._object_status = object_status

    @property
    def identifier(self):
        """
        Gets the identifier of this Project.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this Project.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this Project.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this Project.
        :type: str
        """
        self._identifier = identifier

    @property
    def object_version(self):
        """
        Gets the object_version of this Project.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this Project.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this Project.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this Project.
        :type: int
        """
        self._object_version = object_version

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this Project.

        :return: The parent_ref of this Project.
        :rtype: oci.data_integration.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this Project.

        :param parent_ref: The parent_ref of this Project.
        :type: oci.data_integration.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def metadata(self):
        """
        Gets the metadata of this Project.

        :return: The metadata of this Project.
        :rtype: oci.data_integration.models.ObjectMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this Project.

        :param metadata: The metadata of this Project.
        :type: oci.data_integration.models.ObjectMetadata
        """
        self._metadata = metadata

    @property
    def key_map(self):
        """
        Gets the key_map of this Project.
        A key map. If provided, the key is replaced with generated key. This structure provides mapping between user provided key and generated key.


        :return: The key_map of this Project.
        :rtype: dict(str, str)
        """
        return self._key_map

    @key_map.setter
    def key_map(self, key_map):
        """
        Sets the key_map of this Project.
        A key map. If provided, the key is replaced with generated key. This structure provides mapping between user provided key and generated key.


        :param key_map: The key_map of this Project.
        :type: dict(str, str)
        """
        self._key_map = key_map

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .unique_key import UniqueKey
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UniqueDataKey(UniqueKey):
    """
    The unique key object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UniqueDataKey object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.UniqueDataKey.model_type` attribute
        of this class is ``UNIQUE_KEY`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this UniqueDataKey.
            Allowed values for this property are: "PRIMARY_KEY", "UNIQUE_KEY"
        :type model_type: str

        :param key:
            The value to assign to the key property of this UniqueDataKey.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this UniqueDataKey.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this UniqueDataKey.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param name:
            The value to assign to the name property of this UniqueDataKey.
        :type name: str

        :param attribute_refs:
            The value to assign to the attribute_refs property of this UniqueDataKey.
        :type attribute_refs: list[oci.data_integration.models.KeyAttribute]

        :param object_status:
            The value to assign to the object_status property of this UniqueDataKey.
        :type object_status: int

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'attribute_refs': 'list[KeyAttribute]',
            'object_status': 'int'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'attribute_refs': 'attributeRefs',
            'object_status': 'objectStatus'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._attribute_refs = None
        self._object_status = None
        self._model_type = 'UNIQUE_KEY'

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .instance_configuration_launch_instance_platform_config import InstanceConfigurationLaunchInstancePlatformConfig
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig(InstanceConfigurationLaunchInstancePlatformConfig):
    """
    The platform configuration used when launching a bare metal instance with the BM.Standard.E3.128 shape
    (the AMD Rome platform).
    """

    #: A constant which can be used with the numa_nodes_per_socket property of a InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
    #: This constant has a value of "NPS0"
    NUMA_NODES_PER_SOCKET_NPS0 = "NPS0"

    #: A constant which can be used with the numa_nodes_per_socket property of a InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
    #: This constant has a value of "NPS1"
    NUMA_NODES_PER_SOCKET_NPS1 = "NPS1"

    #: A constant which can be used with the numa_nodes_per_socket property of a InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
    #: This constant has a value of "NPS2"
    NUMA_NODES_PER_SOCKET_NPS2 = "NPS2"

    #: A constant which can be used with the numa_nodes_per_socket property of a InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
    #: This constant has a value of "NPS4"
    NUMA_NODES_PER_SOCKET_NPS4 = "NPS4"

    def __init__(self, **kwargs):
        """
        Initializes a new InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig object with values from keyword arguments. The default value of the :py:attr:`~oci.core.models.InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.type` attribute
        of this class is ``AMD_ROME_BM`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
            Allowed values for this property are: "AMD_MILAN_BM", "AMD_ROME_BM", "AMD_ROME_BM_GPU", "INTEL_ICELAKE_BM", "INTEL_SKYLAKE_BM", "AMD_VM", "INTEL_VM", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param is_secure_boot_enabled:
            The value to assign to the is_secure_boot_enabled property of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        :type is_secure_boot_enabled: bool

        :param is_trusted_platform_module_enabled:
            The value to assign to the is_trusted_platform_module_enabled property of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        :type is_trusted_platform_module_enabled: bool

        :param is_measured_boot_enabled:
            The value to assign to the is_measured_boot_enabled property of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        :type is_measured_boot_enabled: bool

        :param numa_nodes_per_socket:
            The value to assign to the numa_nodes_per_socket property of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
            Allowed values for this property are: "NPS0", "NPS1", "NPS2", "NPS4", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type numa_nodes_per_socket: str

        :param is_symmetric_multi_threading_enabled:
            The value to assign to the is_symmetric_multi_threading_enabled property of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        :type is_symmetric_multi_threading_enabled: bool

        :param is_access_control_service_enabled:
            The value to assign to the is_access_control_service_enabled property of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        :type is_access_control_service_enabled: bool

        :param are_virtual_instructions_enabled:
            The value to assign to the are_virtual_instructions_enabled property of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        :type are_virtual_instructions_enabled: bool

        :param is_input_output_memory_management_unit_enabled:
            The value to assign to the is_input_output_memory_management_unit_enabled property of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        :type is_input_output_memory_management_unit_enabled: bool

        :param percentage_of_cores_enabled:
            The value to assign to the percentage_of_cores_enabled property of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        :type percentage_of_cores_enabled: int

        """
        self.swagger_types = {
            'type': 'str',
            'is_secure_boot_enabled': 'bool',
            'is_trusted_platform_module_enabled': 'bool',
            'is_measured_boot_enabled': 'bool',
            'numa_nodes_per_socket': 'str',
            'is_symmetric_multi_threading_enabled': 'bool',
            'is_access_control_service_enabled': 'bool',
            'are_virtual_instructions_enabled': 'bool',
            'is_input_output_memory_management_unit_enabled': 'bool',
            'percentage_of_cores_enabled': 'int'
        }

        self.attribute_map = {
            'type': 'type',
            'is_secure_boot_enabled': 'isSecureBootEnabled',
            'is_trusted_platform_module_enabled': 'isTrustedPlatformModuleEnabled',
            'is_measured_boot_enabled': 'isMeasuredBootEnabled',
            'numa_nodes_per_socket': 'numaNodesPerSocket',
            'is_symmetric_multi_threading_enabled': 'isSymmetricMultiThreadingEnabled',
            'is_access_control_service_enabled': 'isAccessControlServiceEnabled',
            'are_virtual_instructions_enabled': 'areVirtualInstructionsEnabled',
            'is_input_output_memory_management_unit_enabled': 'isInputOutputMemoryManagementUnitEnabled',
            'percentage_of_cores_enabled': 'percentageOfCoresEnabled'
        }

        self._type = None
        self._is_secure_boot_enabled = None
        self._is_trusted_platform_module_enabled = None
        self._is_measured_boot_enabled = None
        self._numa_nodes_per_socket = None
        self._is_symmetric_multi_threading_enabled = None
        self._is_access_control_service_enabled = None
        self._are_virtual_instructions_enabled = None
        self._is_input_output_memory_management_unit_enabled = None
        self._percentage_of_cores_enabled = None
        self._type = 'AMD_ROME_BM'

    @property
    def numa_nodes_per_socket(self):
        """
        Gets the numa_nodes_per_socket of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        The number of NUMA nodes per socket (NPS).

        Allowed values for this property are: "NPS0", "NPS1", "NPS2", "NPS4", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The numa_nodes_per_socket of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        :rtype: str
        """
        return self._numa_nodes_per_socket

    @numa_nodes_per_socket.setter
    def numa_nodes_per_socket(self, numa_nodes_per_socket):
        """
        Sets the numa_nodes_per_socket of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        The number of NUMA nodes per socket (NPS).


        :param numa_nodes_per_socket: The numa_nodes_per_socket of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        :type: str
        """
        allowed_values = ["NPS0", "NPS1", "NPS2", "NPS4"]
        if not value_allowed_none_or_none_sentinel(numa_nodes_per_socket, allowed_values):
            numa_nodes_per_socket = 'UNKNOWN_ENUM_VALUE'
        self._numa_nodes_per_socket = numa_nodes_per_socket

    @property
    def is_symmetric_multi_threading_enabled(self):
        """
        Gets the is_symmetric_multi_threading_enabled of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        Whether symmetric multithreading is enabled on the instance. Symmetric multithreading is also
        called simultaneous multithreading (SMT) or Intel Hyper-Threading.

        Intel and AMD processors have two hardware execution threads per core (OCPU). SMT permits multiple
        independent threads of execution, to better use the resources and increase the efficiency
        of the CPU. When multithreading is disabled, only one thread is permitted to run on each core, which
        can provide higher or more predictable performance for some workloads.


        :return: The is_symmetric_multi_threading_enabled of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        :rtype: bool
        """
        return self._is_symmetric_multi_threading_enabled

    @is_symmetric_multi_threading_enabled.setter
    def is_symmetric_multi_threading_enabled(self, is_symmetric_multi_threading_enabled):
        """
        Sets the is_symmetric_multi_threading_enabled of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        Whether symmetric multithreading is enabled on the instance. Symmetric multithreading is also
        called simultaneous multithreading (SMT) or Intel Hyper-Threading.

        Intel and AMD processors have two hardware execution threads per core (OCPU). SMT permits multiple
        independent threads of execution, to better use the resources and increase the efficiency
        of the CPU. When multithreading is disabled, only one thread is permitted to run on each core, which
        can provide higher or more predictable performance for some workloads.


        :param is_symmetric_multi_threading_enabled: The is_symmetric_multi_threading_enabled of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        :type: bool
        """
        self._is_symmetric_multi_threading_enabled = is_symmetric_multi_threading_enabled

    @property
    def is_access_control_service_enabled(self):
        """
        Gets the is_access_control_service_enabled of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        Whether the Access Control Service is enabled on the instance. When enabled,
        the platform can enforce PCIe device isolation, required for VFIO device pass-through.


        :return: The is_access_control_service_enabled of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        :rtype: bool
        """
        return self._is_access_control_service_enabled

    @is_access_control_service_enabled.setter
    def is_access_control_service_enabled(self, is_access_control_service_enabled):
        """
        Sets the is_access_control_service_enabled of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        Whether the Access Control Service is enabled on the instance. When enabled,
        the platform can enforce PCIe device isolation, required for VFIO device pass-through.


        :param is_access_control_service_enabled: The is_access_control_service_enabled of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        :type: bool
        """
        self._is_access_control_service_enabled = is_access_control_service_enabled

    @property
    def are_virtual_instructions_enabled(self):
        """
        Gets the are_virtual_instructions_enabled of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        Whether virtualization instructions are available. For example, Secure Virtual Machine for AMD shapes
        or VT-x for Intel shapes.


        :return: The are_virtual_instructions_enabled of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        :rtype: bool
        """
        return self._are_virtual_instructions_enabled

    @are_virtual_instructions_enabled.setter
    def are_virtual_instructions_enabled(self, are_virtual_instructions_enabled):
        """
        Sets the are_virtual_instructions_enabled of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        Whether virtualization instructions are available. For example, Secure Virtual Machine for AMD shapes
        or VT-x for Intel shapes.


        :param are_virtual_instructions_enabled: The are_virtual_instructions_enabled of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        :type: bool
        """
        self._are_virtual_instructions_enabled = are_virtual_instructions_enabled

    @property
    def is_input_output_memory_management_unit_enabled(self):
        """
        Gets the is_input_output_memory_management_unit_enabled of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        Whether the input-output memory management unit is enabled.


        :return: The is_input_output_memory_management_unit_enabled of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        :rtype: bool
        """
        return self._is_input_output_memory_management_unit_enabled

    @is_input_output_memory_management_unit_enabled.setter
    def is_input_output_memory_management_unit_enabled(self, is_input_output_memory_management_unit_enabled):
        """
        Sets the is_input_output_memory_management_unit_enabled of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        Whether the input-output memory management unit is enabled.


        :param is_input_output_memory_management_unit_enabled: The is_input_output_memory_management_unit_enabled of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        :type: bool
        """
        self._is_input_output_memory_management_unit_enabled = is_input_output_memory_management_unit_enabled

    @property
    def percentage_of_cores_enabled(self):
        """
        Gets the percentage_of_cores_enabled of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        The percentage of cores enabled. Value must be a multiple of 25%. If the requested percentage
        results in a fractional number of cores, the system rounds up the number of cores across processors
        and provisions an instance with a whole number of cores.

        If the applications that you run on the instance use a core-based licensing model and need fewer cores
        than the full size of the shape, you can disable cores to reduce your licensing costs. The instance
        itself is billed for the full shape, regardless of whether all cores are enabled.


        :return: The percentage_of_cores_enabled of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        :rtype: int
        """
        return self._percentage_of_cores_enabled

    @percentage_of_cores_enabled.setter
    def percentage_of_cores_enabled(self, percentage_of_cores_enabled):
        """
        Sets the percentage_of_cores_enabled of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        The percentage of cores enabled. Value must be a multiple of 25%. If the requested percentage
        results in a fractional number of cores, the system rounds up the number of cores across processors
        and provisions an instance with a whole number of cores.

        If the applications that you run on the instance use a core-based licensing model and need fewer cores
        than the full size of the shape, you can disable cores to reduce your licensing costs. The instance
        itself is billed for the full shape, regardless of whether all cores are enabled.


        :param percentage_of_cores_enabled: The percentage_of_cores_enabled of this InstanceConfigurationAmdRomeBmLaunchInstancePlatformConfig.
        :type: int
        """
        self._percentage_of_cores_enabled = percentage_of_cores_enabled

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DiscoveryJob(object):
    """
    The DiscoveryJob details.
    """

    #: A constant which can be used with the discovery_type property of a DiscoveryJob.
    #: This constant has a value of "ADD"
    DISCOVERY_TYPE_ADD = "ADD"

    #: A constant which can be used with the discovery_type property of a DiscoveryJob.
    #: This constant has a value of "ADD_WITH_RETRY"
    DISCOVERY_TYPE_ADD_WITH_RETRY = "ADD_WITH_RETRY"

    #: A constant which can be used with the discovery_type property of a DiscoveryJob.
    #: This constant has a value of "REFRESH"
    DISCOVERY_TYPE_REFRESH = "REFRESH"

    #: A constant which can be used with the status property of a DiscoveryJob.
    #: This constant has a value of "SUCCESS"
    STATUS_SUCCESS = "SUCCESS"

    #: A constant which can be used with the status property of a DiscoveryJob.
    #: This constant has a value of "FAILURE"
    STATUS_FAILURE = "FAILURE"

    #: A constant which can be used with the status property of a DiscoveryJob.
    #: This constant has a value of "INPROGRESS"
    STATUS_INPROGRESS = "INPROGRESS"

    #: A constant which can be used with the status property of a DiscoveryJob.
    #: This constant has a value of "INACTIVE"
    STATUS_INACTIVE = "INACTIVE"

    #: A constant which can be used with the status property of a DiscoveryJob.
    #: This constant has a value of "CREATED"
    STATUS_CREATED = "CREATED"

    #: A constant which can be used with the status property of a DiscoveryJob.
    #: This constant has a value of "DELETED"
    STATUS_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a DiscoveryJob.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a DiscoveryJob.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a DiscoveryJob.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a DiscoveryJob.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a DiscoveryJob.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a DiscoveryJob.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new DiscoveryJob object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this DiscoveryJob.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this DiscoveryJob.
        :type compartment_id: str

        :param discovery_type:
            The value to assign to the discovery_type property of this DiscoveryJob.
            Allowed values for this property are: "ADD", "ADD_WITH_RETRY", "REFRESH", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type discovery_type: str

        :param status:
            The value to assign to the status property of this DiscoveryJob.
            Allowed values for this property are: "SUCCESS", "FAILURE", "INPROGRESS", "INACTIVE", "CREATED", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param status_message:
            The value to assign to the status_message property of this DiscoveryJob.
        :type status_message: str

        :param tenant_id:
            The value to assign to the tenant_id property of this DiscoveryJob.
        :type tenant_id: str

        :param user_id:
            The value to assign to the user_id property of this DiscoveryJob.
        :type user_id: str

        :param discovery_client:
            The value to assign to the discovery_client property of this DiscoveryJob.
        :type discovery_client: str

        :param discovery_details:
            The value to assign to the discovery_details property of this DiscoveryJob.
        :type discovery_details: oci.stack_monitoring.models.DiscoveryDetails

        :param time_updated:
            The value to assign to the time_updated property of this DiscoveryJob.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DiscoveryJob.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this DiscoveryJob.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this DiscoveryJob.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this DiscoveryJob.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'discovery_type': 'str',
            'status': 'str',
            'status_message': 'str',
            'tenant_id': 'str',
            'user_id': 'str',
            'discovery_client': 'str',
            'discovery_details': 'DiscoveryDetails',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'discovery_type': 'discoveryType',
            'status': 'status',
            'status_message': 'statusMessage',
            'tenant_id': 'tenantId',
            'user_id': 'userId',
            'discovery_client': 'discoveryClient',
            'discovery_details': 'discoveryDetails',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._id = None
        self._compartment_id = None
        self._discovery_type = None
        self._status = None
        self._status_message = None
        self._tenant_id = None
        self._user_id = None
        self._discovery_client = None
        self._discovery_details = None
        self._time_updated = None
        self._lifecycle_state = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this DiscoveryJob.
        The OCID of Discovery job


        :return: The id of this DiscoveryJob.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DiscoveryJob.
        The OCID of Discovery job


        :param id: The id of this DiscoveryJob.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this DiscoveryJob.
        The OCID of the Compartment


        :return: The compartment_id of this DiscoveryJob.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DiscoveryJob.
        The OCID of the Compartment


        :param compartment_id: The compartment_id of this DiscoveryJob.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def discovery_type(self):
        """
        Gets the discovery_type of this DiscoveryJob.
        Add option submits new discovery Job. Add with retry option to re-submit failed discovery job. Refresh option refreshes the existing discovered resources.

        Allowed values for this property are: "ADD", "ADD_WITH_RETRY", "REFRESH", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The discovery_type of this DiscoveryJob.
        :rtype: str
        """
        return self._discovery_type

    @discovery_type.setter
    def discovery_type(self, discovery_type):
        """
        Sets the discovery_type of this DiscoveryJob.
        Add option submits new discovery Job. Add with retry option to re-submit failed discovery job. Refresh option refreshes the existing discovered resources.


        :param discovery_type: The discovery_type of this DiscoveryJob.
        :type: str
        """
        allowed_values = ["ADD", "ADD_WITH_RETRY", "REFRESH"]
        if not value_allowed_none_or_none_sentinel(discovery_type, allowed_values):
            discovery_type = 'UNKNOWN_ENUM_VALUE'
        self._discovery_type = discovery_type

    @property
    def status(self):
        """
        Gets the status of this DiscoveryJob.
        Specifies the status of the discovery job

        Allowed values for this property are: "SUCCESS", "FAILURE", "INPROGRESS", "INACTIVE", "CREATED", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this DiscoveryJob.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this DiscoveryJob.
        Specifies the status of the discovery job


        :param status: The status of this DiscoveryJob.
        :type: str
        """
        allowed_values = ["SUCCESS", "FAILURE", "INPROGRESS", "INACTIVE", "CREATED", "DELETED"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def status_message(self):
        """
        Gets the status_message of this DiscoveryJob.
        The short summary of the status of the discovery job


        :return: The status_message of this DiscoveryJob.
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """
        Sets the status_message of this DiscoveryJob.
        The short summary of the status of the discovery job


        :param status_message: The status_message of this DiscoveryJob.
        :type: str
        """
        self._status_message = status_message

    @property
    def tenant_id(self):
        """
        Gets the tenant_id of this DiscoveryJob.
        The OCID of Tenant


        :return: The tenant_id of this DiscoveryJob.
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """
        Sets the tenant_id of this DiscoveryJob.
        The OCID of Tenant


        :param tenant_id: The tenant_id of this DiscoveryJob.
        :type: str
        """
        self._tenant_id = tenant_id

    @property
    def user_id(self):
        """
        Gets the user_id of this DiscoveryJob.
        The OCID of user in which the job is submitted


        :return: The user_id of this DiscoveryJob.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this DiscoveryJob.
        The OCID of user in which the job is submitted


        :param user_id: The user_id of this DiscoveryJob.
        :type: str
        """
        self._user_id = user_id

    @property
    def discovery_client(self):
        """
        Gets the discovery_client of this DiscoveryJob.
        Client who submits discovery job.


        :return: The discovery_client of this DiscoveryJob.
        :rtype: str
        """
        return self._discovery_client

    @discovery_client.setter
    def discovery_client(self, discovery_client):
        """
        Sets the discovery_client of this DiscoveryJob.
        Client who submits discovery job.


        :param discovery_client: The discovery_client of this DiscoveryJob.
        :type: str
        """
        self._discovery_client = discovery_client

    @property
    def discovery_details(self):
        """
        Gets the discovery_details of this DiscoveryJob.

        :return: The discovery_details of this DiscoveryJob.
        :rtype: oci.stack_monitoring.models.DiscoveryDetails
        """
        return self._discovery_details

    @discovery_details.setter
    def discovery_details(self, discovery_details):
        """
        Sets the discovery_details of this DiscoveryJob.

        :param discovery_details: The discovery_details of this DiscoveryJob.
        :type: oci.stack_monitoring.models.DiscoveryDetails
        """
        self._discovery_details = discovery_details

    @property
    def time_updated(self):
        """
        Gets the time_updated of this DiscoveryJob.
        The time the discovery Job was updated.


        :return: The time_updated of this DiscoveryJob.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this DiscoveryJob.
        The time the discovery Job was updated.


        :param time_updated: The time_updated of this DiscoveryJob.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this DiscoveryJob.
        The current state of the DiscoveryJob Resource.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this DiscoveryJob.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this DiscoveryJob.
        The current state of the DiscoveryJob Resource.


        :param lifecycle_state: The lifecycle_state of this DiscoveryJob.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this DiscoveryJob.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this DiscoveryJob.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this DiscoveryJob.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this DiscoveryJob.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this DiscoveryJob.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this DiscoveryJob.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this DiscoveryJob.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this DiscoveryJob.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this DiscoveryJob.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this DiscoveryJob.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this DiscoveryJob.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this DiscoveryJob.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class EntitlementSummary(object):
    """
    A summary of an entitlement included in a usage plan.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new EntitlementSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this EntitlementSummary.
        :type name: str

        :param description:
            The value to assign to the description property of this EntitlementSummary.
        :type description: str

        :param rate_limit:
            The value to assign to the rate_limit property of this EntitlementSummary.
        :type rate_limit: oci.apigateway.models.RateLimit

        :param quota:
            The value to assign to the quota property of this EntitlementSummary.
        :type quota: oci.apigateway.models.Quota

        """
        self.swagger_types = {
            'name': 'str',
            'description': 'str',
            'rate_limit': 'RateLimit',
            'quota': 'Quota'
        }

        self.attribute_map = {
            'name': 'name',
            'description': 'description',
            'rate_limit': 'rateLimit',
            'quota': 'quota'
        }

        self._name = None
        self._description = None
        self._rate_limit = None
        self._quota = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this EntitlementSummary.
        An entitlement name, unique within a usage plan.


        :return: The name of this EntitlementSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this EntitlementSummary.
        An entitlement name, unique within a usage plan.


        :param name: The name of this EntitlementSummary.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this EntitlementSummary.
        A user-friendly description. To provide some insight about the resource.
        Avoid entering confidential information.


        :return: The description of this EntitlementSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this EntitlementSummary.
        A user-friendly description. To provide some insight about the resource.
        Avoid entering confidential information.


        :param description: The description of this EntitlementSummary.
        :type: str
        """
        self._description = description

    @property
    def rate_limit(self):
        """
        Gets the rate_limit of this EntitlementSummary.

        :return: The rate_limit of this EntitlementSummary.
        :rtype: oci.apigateway.models.RateLimit
        """
        return self._rate_limit

    @rate_limit.setter
    def rate_limit(self, rate_limit):
        """
        Sets the rate_limit of this EntitlementSummary.

        :param rate_limit: The rate_limit of this EntitlementSummary.
        :type: oci.apigateway.models.RateLimit
        """
        self._rate_limit = rate_limit

    @property
    def quota(self):
        """
        Gets the quota of this EntitlementSummary.

        :return: The quota of this EntitlementSummary.
        :rtype: oci.apigateway.models.Quota
        """
        return self._quota

    @quota.setter
    def quota(self, quota):
        """
        Sets the quota of this EntitlementSummary.

        :param quota: The quota of this EntitlementSummary.
        :type: oci.apigateway.models.Quota
        """
        self._quota = quota

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResourceProfileEndpointSummary(object):
    """
    Resource Profile Endpoints summary.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ResourceProfileEndpointSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ResourceProfileEndpointSummary.
        :type id: str

        :param resource_profile_id:
            The value to assign to the resource_profile_id property of this ResourceProfileEndpointSummary.
        :type resource_profile_id: str

        :param problem_id:
            The value to assign to the problem_id property of this ResourceProfileEndpointSummary.
        :type problem_id: str

        :param sighting_type:
            The value to assign to the sighting_type property of this ResourceProfileEndpointSummary.
        :type sighting_type: str

        :param sighting_type_display_name:
            The value to assign to the sighting_type_display_name property of this ResourceProfileEndpointSummary.
        :type sighting_type_display_name: str

        :param ip_address:
            The value to assign to the ip_address property of this ResourceProfileEndpointSummary.
        :type ip_address: str

        :param ip_address_type:
            The value to assign to the ip_address_type property of this ResourceProfileEndpointSummary.
        :type ip_address_type: str

        :param ip_classification_type:
            The value to assign to the ip_classification_type property of this ResourceProfileEndpointSummary.
        :type ip_classification_type: str

        :param country:
            The value to assign to the country property of this ResourceProfileEndpointSummary.
        :type country: str

        :param latitude:
            The value to assign to the latitude property of this ResourceProfileEndpointSummary.
        :type latitude: float

        :param longitude:
            The value to assign to the longitude property of this ResourceProfileEndpointSummary.
        :type longitude: float

        :param asn_number:
            The value to assign to the asn_number property of this ResourceProfileEndpointSummary.
        :type asn_number: str

        :param regions:
            The value to assign to the regions property of this ResourceProfileEndpointSummary.
        :type regions: list[str]

        :param services:
            The value to assign to the services property of this ResourceProfileEndpointSummary.
        :type services: list[str]

        :param time_last_detected:
            The value to assign to the time_last_detected property of this ResourceProfileEndpointSummary.
        :type time_last_detected: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'resource_profile_id': 'str',
            'problem_id': 'str',
            'sighting_type': 'str',
            'sighting_type_display_name': 'str',
            'ip_address': 'str',
            'ip_address_type': 'str',
            'ip_classification_type': 'str',
            'country': 'str',
            'latitude': 'float',
            'longitude': 'float',
            'asn_number': 'str',
            'regions': 'list[str]',
            'services': 'list[str]',
            'time_last_detected': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'resource_profile_id': 'resourceProfileId',
            'problem_id': 'problemId',
            'sighting_type': 'sightingType',
            'sighting_type_display_name': 'sightingTypeDisplayName',
            'ip_address': 'ipAddress',
            'ip_address_type': 'ipAddressType',
            'ip_classification_type': 'ipClassificationType',
            'country': 'country',
            'latitude': 'latitude',
            'longitude': 'longitude',
            'asn_number': 'asnNumber',
            'regions': 'regions',
            'services': 'services',
            'time_last_detected': 'timeLastDetected'
        }

        self._id = None
        self._resource_profile_id = None
        self._problem_id = None
        self._sighting_type = None
        self._sighting_type_display_name = None
        self._ip_address = None
        self._ip_address_type = None
        self._ip_classification_type = None
        self._country = None
        self._latitude = None
        self._longitude = None
        self._asn_number = None
        self._regions = None
        self._services = None
        self._time_last_detected = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ResourceProfileEndpointSummary.
        Unique identifier for sighting endpoints


        :return: The id of this ResourceProfileEndpointSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ResourceProfileEndpointSummary.
        Unique identifier for sighting endpoints


        :param id: The id of this ResourceProfileEndpointSummary.
        :type: str
        """
        self._id = id

    @property
    def resource_profile_id(self):
        """
        **[Required]** Gets the resource_profile_id of this ResourceProfileEndpointSummary.
        Resource profile Id associated with the imacted resource


        :return: The resource_profile_id of this ResourceProfileEndpointSummary.
        :rtype: str
        """
        return self._resource_profile_id

    @resource_profile_id.setter
    def resource_profile_id(self, resource_profile_id):
        """
        Sets the resource_profile_id of this ResourceProfileEndpointSummary.
        Resource profile Id associated with the imacted resource


        :param resource_profile_id: The resource_profile_id of this ResourceProfileEndpointSummary.
        :type: str
        """
        self._resource_profile_id = resource_profile_id

    @property
    def problem_id(self):
        """
        Gets the problem_id of this ResourceProfileEndpointSummary.
        Problem Id for sighting endpoints


        :return: The problem_id of this ResourceProfileEndpointSummary.
        :rtype: str
        """
        return self._problem_id

    @problem_id.setter
    def problem_id(self, problem_id):
        """
        Sets the problem_id of this ResourceProfileEndpointSummary.
        Problem Id for sighting endpoints


        :param problem_id: The problem_id of this ResourceProfileEndpointSummary.
        :type: str
        """
        self._problem_id = problem_id

    @property
    def sighting_type(self):
        """
        **[Required]** Gets the sighting_type of this ResourceProfileEndpointSummary.
        Identifier for the sighting type


        :return: The sighting_type of this ResourceProfileEndpointSummary.
        :rtype: str
        """
        return self._sighting_type

    @sighting_type.setter
    def sighting_type(self, sighting_type):
        """
        Sets the sighting_type of this ResourceProfileEndpointSummary.
        Identifier for the sighting type


        :param sighting_type: The sighting_type of this ResourceProfileEndpointSummary.
        :type: str
        """
        self._sighting_type = sighting_type

    @property
    def sighting_type_display_name(self):
        """
        **[Required]** Gets the sighting_type_display_name of this ResourceProfileEndpointSummary.
        Name of the sighting type


        :return: The sighting_type_display_name of this ResourceProfileEndpointSummary.
        :rtype: str
        """
        return self._sighting_type_display_name

    @sighting_type_display_name.setter
    def sighting_type_display_name(self, sighting_type_display_name):
        """
        Sets the sighting_type_display_name of this ResourceProfileEndpointSummary.
        Name of the sighting type


        :param sighting_type_display_name: The sighting_type_display_name of this ResourceProfileEndpointSummary.
        :type: str
        """
        self._sighting_type_display_name = sighting_type_display_name

    @property
    def ip_address(self):
        """
        **[Required]** Gets the ip_address of this ResourceProfileEndpointSummary.
        IP Address


        :return: The ip_address of this ResourceProfileEndpointSummary.
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """
        Sets the ip_address of this ResourceProfileEndpointSummary.
        IP Address


        :param ip_address: The ip_address of this ResourceProfileEndpointSummary.
        :type: str
        """
        self._ip_address = ip_address

    @property
    def ip_address_type(self):
        """
        **[Required]** Gets the ip_address_type of this ResourceProfileEndpointSummary.
        IP Address type


        :return: The ip_address_type of this ResourceProfileEndpointSummary.
        :rtype: str
        """
        return self._ip_address_type

    @ip_address_type.setter
    def ip_address_type(self, ip_address_type):
        """
        Sets the ip_address_type of this ResourceProfileEndpointSummary.
        IP Address type


        :param ip_address_type: The ip_address_type of this ResourceProfileEndpointSummary.
        :type: str
        """
        self._ip_address_type = ip_address_type

    @property
    def ip_classification_type(self):
        """
        Gets the ip_classification_type of this ResourceProfileEndpointSummary.
        IP Address classification type


        :return: The ip_classification_type of this ResourceProfileEndpointSummary.
        :rtype: str
        """
        return self._ip_classification_type

    @ip_classification_type.setter
    def ip_classification_type(self, ip_classification_type):
        """
        Sets the ip_classification_type of this ResourceProfileEndpointSummary.
        IP Address classification type


        :param ip_classification_type: The ip_classification_type of this ResourceProfileEndpointSummary.
        :type: str
        """
        self._ip_classification_type = ip_classification_type

    @property
    def country(self):
        """
        Gets the country of this ResourceProfileEndpointSummary.
        Country


        :return: The country of this ResourceProfileEndpointSummary.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this ResourceProfileEndpointSummary.
        Country


        :param country: The country of this ResourceProfileEndpointSummary.
        :type: str
        """
        self._country = country

    @property
    def latitude(self):
        """
        Gets the latitude of this ResourceProfileEndpointSummary.
        Latitude


        :return: The latitude of this ResourceProfileEndpointSummary.
        :rtype: float
        """
        return self._latitude

    @latitude.setter
    def latitude(self, latitude):
        """
        Sets the latitude of this ResourceProfileEndpointSummary.
        Latitude


        :param latitude: The latitude of this ResourceProfileEndpointSummary.
        :type: float
        """
        self._latitude = latitude

    @property
    def longitude(self):
        """
        Gets the longitude of this ResourceProfileEndpointSummary.
        Longitude


        :return: The longitude of this ResourceProfileEndpointSummary.
        :rtype: float
        """
        return self._longitude

    @longitude.setter
    def longitude(self, longitude):
        """
        Sets the longitude of this ResourceProfileEndpointSummary.
        Longitude


        :param longitude: The longitude of this ResourceProfileEndpointSummary.
        :type: float
        """
        self._longitude = longitude

    @property
    def asn_number(self):
        """
        Gets the asn_number of this ResourceProfileEndpointSummary.
        ASN number


        :return: The asn_number of this ResourceProfileEndpointSummary.
        :rtype: str
        """
        return self._asn_number

    @asn_number.setter
    def asn_number(self, asn_number):
        """
        Sets the asn_number of this ResourceProfileEndpointSummary.
        ASN number


        :param asn_number: The asn_number of this ResourceProfileEndpointSummary.
        :type: str
        """
        self._asn_number = asn_number

    @property
    def regions(self):
        """
        Gets the regions of this ResourceProfileEndpointSummary.
        Regions where activities were performed from this IP


        :return: The regions of this ResourceProfileEndpointSummary.
        :rtype: list[str]
        """
        return self._regions

    @regions.setter
    def regions(self, regions):
        """
        Sets the regions of this ResourceProfileEndpointSummary.
        Regions where activities were performed from this IP


        :param regions: The regions of this ResourceProfileEndpointSummary.
        :type: list[str]
        """
        self._regions = regions

    @property
    def services(self):
        """
        Gets the services of this ResourceProfileEndpointSummary.
        Services where activities were performed from this IP


        :return: The services of this ResourceProfileEndpointSummary.
        :rtype: list[str]
        """
        return self._services

    @services.setter
    def services(self, services):
        """
        Sets the services of this ResourceProfileEndpointSummary.
        Services where activities were performed from this IP


        :param services: The services of this ResourceProfileEndpointSummary.
        :type: list[str]
        """
        self._services = services

    @property
    def time_last_detected(self):
        """
        **[Required]** Gets the time_last_detected of this ResourceProfileEndpointSummary.
        Time when activities were created


        :return: The time_last_detected of this ResourceProfileEndpointSummary.
        :rtype: datetime
        """
        return self._time_last_detected

    @time_last_detected.setter
    def time_last_detected(self, time_last_detected):
        """
        Sets the time_last_detected of this ResourceProfileEndpointSummary.
        Time when activities were created


        :param time_last_detected: The time_last_detected of this ResourceProfileEndpointSummary.
        :type: datetime
        """
        self._time_last_detected = time_last_detected

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .dp_endpoint_details import DpEndpointDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DpEndpointFromPrivateDetails(DpEndpointDetails):
    """
    The endpoint details for a private endpoint.
    """

    #: A constant which can be used with the state property of a DpEndpointFromPrivateDetails.
    #: This constant has a value of "ACTIVE"
    STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the state property of a DpEndpointFromPrivateDetails.
    #: This constant has a value of "INACTIVE"
    STATE_INACTIVE = "INACTIVE"

    def __init__(self, **kwargs):
        """
        Initializes a new DpEndpointFromPrivateDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.data_connectivity.models.DpEndpointFromPrivateDetails.model_type` attribute
        of this class is ``PRIVATE_END_POINT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this DpEndpointFromPrivateDetails.
            Allowed values for this property are: "PRIVATE_END_POINT", "PUBLIC_END_POINT"
        :type model_type: str

        :param key:
            The value to assign to the key property of this DpEndpointFromPrivateDetails.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this DpEndpointFromPrivateDetails.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this DpEndpointFromPrivateDetails.
        :type parent_ref: oci.data_connectivity.models.ParentReference

        :param name:
            The value to assign to the name property of this DpEndpointFromPrivateDetails.
        :type name: str

        :param description:
            The value to assign to the description property of this DpEndpointFromPrivateDetails.
        :type description: str

        :param object_version:
            The value to assign to the object_version property of this DpEndpointFromPrivateDetails.
        :type object_version: int

        :param object_status:
            The value to assign to the object_status property of this DpEndpointFromPrivateDetails.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this DpEndpointFromPrivateDetails.
        :type identifier: str

        :param data_assets:
            The value to assign to the data_assets property of this DpEndpointFromPrivateDetails.
        :type data_assets: list[oci.data_connectivity.models.DataAsset]

        :param dcms_endpoint_id:
            The value to assign to the dcms_endpoint_id property of this DpEndpointFromPrivateDetails.
        :type dcms_endpoint_id: str

        :param pe_id:
            The value to assign to the pe_id property of this DpEndpointFromPrivateDetails.
        :type pe_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this DpEndpointFromPrivateDetails.
        :type compartment_id: str

        :param dns_proxy_ip:
            The value to assign to the dns_proxy_ip property of this DpEndpointFromPrivateDetails.
        :type dns_proxy_ip: str

        :param private_endpoint_ip:
            The value to assign to the private_endpoint_ip property of this DpEndpointFromPrivateDetails.
        :type private_endpoint_ip: str

        :param dns_zones:
            The value to assign to the dns_zones property of this DpEndpointFromPrivateDetails.
        :type dns_zones: list[str]

        :param state:
            The value to assign to the state property of this DpEndpointFromPrivateDetails.
            Allowed values for this property are: "ACTIVE", "INACTIVE"
        :type state: str

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'description': 'str',
            'object_version': 'int',
            'object_status': 'int',
            'identifier': 'str',
            'data_assets': 'list[DataAsset]',
            'dcms_endpoint_id': 'str',
            'pe_id': 'str',
            'compartment_id': 'str',
            'dns_proxy_ip': 'str',
            'private_endpoint_ip': 'str',
            'dns_zones': 'list[str]',
            'state': 'str'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'description': 'description',
            'object_version': 'objectVersion',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'data_assets': 'dataAssets',
            'dcms_endpoint_id': 'dcmsEndpointId',
            'pe_id': 'peId',
            'compartment_id': 'compartmentId',
            'dns_proxy_ip': 'dnsProxyIp',
            'private_endpoint_ip': 'privateEndpointIp',
            'dns_zones': 'dnsZones',
            'state': 'state'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._description = None
        self._object_version = None
        self._object_status = None
        self._identifier = None
        self._data_assets = None
        self._dcms_endpoint_id = None
        self._pe_id = None
        self._compartment_id = None
        self._dns_proxy_ip = None
        self._private_endpoint_ip = None
        self._dns_zones = None
        self._state = None
        self._model_type = 'PRIVATE_END_POINT'

    @property
    def dcms_endpoint_id(self):
        """
        **[Required]** Gets the dcms_endpoint_id of this DpEndpointFromPrivateDetails.
        The endpoint ID provided by control plane.


        :return: The dcms_endpoint_id of this DpEndpointFromPrivateDetails.
        :rtype: str
        """
        return self._dcms_endpoint_id

    @dcms_endpoint_id.setter
    def dcms_endpoint_id(self, dcms_endpoint_id):
        """
        Sets the dcms_endpoint_id of this DpEndpointFromPrivateDetails.
        The endpoint ID provided by control plane.


        :param dcms_endpoint_id: The dcms_endpoint_id of this DpEndpointFromPrivateDetails.
        :type: str
        """
        self._dcms_endpoint_id = dcms_endpoint_id

    @property
    def pe_id(self):
        """
        Gets the pe_id of this DpEndpointFromPrivateDetails.
        The ocid of private endpoint resource.


        :return: The pe_id of this DpEndpointFromPrivateDetails.
        :rtype: str
        """
        return self._pe_id

    @pe_id.setter
    def pe_id(self, pe_id):
        """
        Sets the pe_id of this DpEndpointFromPrivateDetails.
        The ocid of private endpoint resource.


        :param pe_id: The pe_id of this DpEndpointFromPrivateDetails.
        :type: str
        """
        self._pe_id = pe_id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this DpEndpointFromPrivateDetails.
        The compartmentId of private endpoint resource.


        :return: The compartment_id of this DpEndpointFromPrivateDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DpEndpointFromPrivateDetails.
        The compartmentId of private endpoint resource.


        :param compartment_id: The compartment_id of this DpEndpointFromPrivateDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def dns_proxy_ip(self):
        """
        Gets the dns_proxy_ip of this DpEndpointFromPrivateDetails.
        The IP address of dns proxy.


        :return: The dns_proxy_ip of this DpEndpointFromPrivateDetails.
        :rtype: str
        """
        return self._dns_proxy_ip

    @dns_proxy_ip.setter
    def dns_proxy_ip(self, dns_proxy_ip):
        """
        Sets the dns_proxy_ip of this DpEndpointFromPrivateDetails.
        The IP address of dns proxy.


        :param dns_proxy_ip: The dns_proxy_ip of this DpEndpointFromPrivateDetails.
        :type: str
        """
        self._dns_proxy_ip = dns_proxy_ip

    @property
    def private_endpoint_ip(self):
        """
        Gets the private_endpoint_ip of this DpEndpointFromPrivateDetails.
        The ocid of private endpoint resource.


        :return: The private_endpoint_ip of this DpEndpointFromPrivateDetails.
        :rtype: str
        """
        return self._private_endpoint_ip

    @private_endpoint_ip.setter
    def private_endpoint_ip(self, private_endpoint_ip):
        """
        Sets the private_endpoint_ip of this DpEndpointFromPrivateDetails.
        The ocid of private endpoint resource.


        :param private_endpoint_ip: The private_endpoint_ip of this DpEndpointFromPrivateDetails.
        :type: str
        """
        self._private_endpoint_ip = private_endpoint_ip

    @property
    def dns_zones(self):
        """
        Gets the dns_zones of this DpEndpointFromPrivateDetails.
        Array of dns zones to be use during private endpoint resolution.


        :return: The dns_zones of this DpEndpointFromPrivateDetails.
        :rtype: list[str]
        """
        return self._dns_zones

    @dns_zones.setter
    def dns_zones(self, dns_zones):
        """
        Sets the dns_zones of this DpEndpointFromPrivateDetails.
        Array of dns zones to be use during private endpoint resolution.


        :param dns_zones: The dns_zones of this DpEndpointFromPrivateDetails.
        :type: list[str]
        """
        self._dns_zones = dns_zones

    @property
    def state(self):
        """
        Gets the state of this DpEndpointFromPrivateDetails.
        Specifies the private endpoint state.

        Allowed values for this property are: "ACTIVE", "INACTIVE"


        :return: The state of this DpEndpointFromPrivateDetails.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this DpEndpointFromPrivateDetails.
        Specifies the private endpoint state.


        :param state: The state of this DpEndpointFromPrivateDetails.
        :type: str
        """
        allowed_values = ["ACTIVE", "INACTIVE"]
        if not value_allowed_none_or_none_sentinel(state, allowed_values):
            raise ValueError(
                "Invalid value for `state`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._state = state

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ReferenceArtifactSummary(object):
    """
    Represents Reference details of a data asset.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ReferenceArtifactSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this ReferenceArtifactSummary.
        :type model_type: str

        :param key:
            The value to assign to the key property of this ReferenceArtifactSummary.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this ReferenceArtifactSummary.
        :type model_version: str

        :param name:
            The value to assign to the name property of this ReferenceArtifactSummary.
        :type name: str

        :param description:
            The value to assign to the description property of this ReferenceArtifactSummary.
        :type description: str

        :param object_status:
            The value to assign to the object_status property of this ReferenceArtifactSummary.
        :type object_status: int

        :param object_version:
            The value to assign to the object_version property of this ReferenceArtifactSummary.
        :type object_version: int

        :param identifier:
            The value to assign to the identifier property of this ReferenceArtifactSummary.
        :type identifier: str

        :param dcms_artifact_id:
            The value to assign to the dcms_artifact_id property of this ReferenceArtifactSummary.
        :type dcms_artifact_id: str

        :param service_artifact_id:
            The value to assign to the service_artifact_id property of this ReferenceArtifactSummary.
        :type service_artifact_id: str

        :param reference_count:
            The value to assign to the reference_count property of this ReferenceArtifactSummary.
        :type reference_count: int

        :param registry_metadata:
            The value to assign to the registry_metadata property of this ReferenceArtifactSummary.
        :type registry_metadata: oci.data_connectivity.models.RegistryMetadata

        :param metadata:
            The value to assign to the metadata property of this ReferenceArtifactSummary.
        :type metadata: oci.data_connectivity.models.ObjectMetadata

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'name': 'str',
            'description': 'str',
            'object_status': 'int',
            'object_version': 'int',
            'identifier': 'str',
            'dcms_artifact_id': 'str',
            'service_artifact_id': 'str',
            'reference_count': 'int',
            'registry_metadata': 'RegistryMetadata',
            'metadata': 'ObjectMetadata'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'name': 'name',
            'description': 'description',
            'object_status': 'objectStatus',
            'object_version': 'objectVersion',
            'identifier': 'identifier',
            'dcms_artifact_id': 'dcmsArtifactId',
            'service_artifact_id': 'serviceArtifactId',
            'reference_count': 'referenceCount',
            'registry_metadata': 'registryMetadata',
            'metadata': 'metadata'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._name = None
        self._description = None
        self._object_status = None
        self._object_version = None
        self._identifier = None
        self._dcms_artifact_id = None
        self._service_artifact_id = None
        self._reference_count = None
        self._registry_metadata = None
        self._metadata = None

    @property
    def model_type(self):
        """
        **[Required]** Gets the model_type of this ReferenceArtifactSummary.
        The type of the ReferenceInfo.


        :return: The model_type of this ReferenceArtifactSummary.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this ReferenceArtifactSummary.
        The type of the ReferenceInfo.


        :param model_type: The model_type of this ReferenceArtifactSummary.
        :type: str
        """
        self._model_type = model_type

    @property
    def key(self):
        """
        Gets the key of this ReferenceArtifactSummary.
        Generated key that can be used in API calls to identify referenceinfo.


        :return: The key of this ReferenceArtifactSummary.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this ReferenceArtifactSummary.
        Generated key that can be used in API calls to identify referenceinfo.


        :param key: The key of this ReferenceArtifactSummary.
        :type: str
        """
        self._key = key

    @property
    def model_version(self):
        """
        Gets the model_version of this ReferenceArtifactSummary.
        The model version of an object.


        :return: The model_version of this ReferenceArtifactSummary.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this ReferenceArtifactSummary.
        The model version of an object.


        :param model_version: The model_version of this ReferenceArtifactSummary.
        :type: str
        """
        self._model_version = model_version

    @property
    def name(self):
        """
        Gets the name of this ReferenceArtifactSummary.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this ReferenceArtifactSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ReferenceArtifactSummary.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this ReferenceArtifactSummary.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this ReferenceArtifactSummary.
        User-defined description of the referenceInfo.


        :return: The description of this ReferenceArtifactSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ReferenceArtifactSummary.
        User-defined description of the referenceInfo.


        :param description: The description of this ReferenceArtifactSummary.
        :type: str
        """
        self._description = description

    @property
    def object_status(self):
        """
        Gets the object_status of this ReferenceArtifactSummary.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this ReferenceArtifactSummary.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this ReferenceArtifactSummary.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this ReferenceArtifactSummary.
        :type: int
        """
        self._object_status = object_status

    @property
    def object_version(self):
        """
        Gets the object_version of this ReferenceArtifactSummary.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this ReferenceArtifactSummary.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this ReferenceArtifactSummary.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this ReferenceArtifactSummary.
        :type: int
        """
        self._object_version = object_version

    @property
    def identifier(self):
        """
        Gets the identifier of this ReferenceArtifactSummary.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this ReferenceArtifactSummary.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this ReferenceArtifactSummary.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this ReferenceArtifactSummary.
        :type: str
        """
        self._identifier = identifier

    @property
    def dcms_artifact_id(self):
        """
        Gets the dcms_artifact_id of this ReferenceArtifactSummary.
        unique id of dcms artifact that is getting registered.


        :return: The dcms_artifact_id of this ReferenceArtifactSummary.
        :rtype: str
        """
        return self._dcms_artifact_id

    @dcms_artifact_id.setter
    def dcms_artifact_id(self, dcms_artifact_id):
        """
        Sets the dcms_artifact_id of this ReferenceArtifactSummary.
        unique id of dcms artifact that is getting registered.


        :param dcms_artifact_id: The dcms_artifact_id of this ReferenceArtifactSummary.
        :type: str
        """
        self._dcms_artifact_id = dcms_artifact_id

    @property
    def service_artifact_id(self):
        """
        **[Required]** Gets the service_artifact_id of this ReferenceArtifactSummary.
        unique id of service which is referencing dcms artifact.


        :return: The service_artifact_id of this ReferenceArtifactSummary.
        :rtype: str
        """
        return self._service_artifact_id

    @service_artifact_id.setter
    def service_artifact_id(self, service_artifact_id):
        """
        Sets the service_artifact_id of this ReferenceArtifactSummary.
        unique id of service which is referencing dcms artifact.


        :param service_artifact_id: The service_artifact_id of this ReferenceArtifactSummary.
        :type: str
        """
        self._service_artifact_id = service_artifact_id

    @property
    def reference_count(self):
        """
        Gets the reference_count of this ReferenceArtifactSummary.
        count of how many times a dcms artifact has been registered by a service.


        :return: The reference_count of this ReferenceArtifactSummary.
        :rtype: int
        """
        return self._reference_count

    @reference_count.setter
    def reference_count(self, reference_count):
        """
        Sets the reference_count of this ReferenceArtifactSummary.
        count of how many times a dcms artifact has been registered by a service.


        :param reference_count: The reference_count of this ReferenceArtifactSummary.
        :type: int
        """
        self._reference_count = reference_count

    @property
    def registry_metadata(self):
        """
        Gets the registry_metadata of this ReferenceArtifactSummary.

        :return: The registry_metadata of this ReferenceArtifactSummary.
        :rtype: oci.data_connectivity.models.RegistryMetadata
        """
        return self._registry_metadata

    @registry_metadata.setter
    def registry_metadata(self, registry_metadata):
        """
        Sets the registry_metadata of this ReferenceArtifactSummary.

        :param registry_metadata: The registry_metadata of this ReferenceArtifactSummary.
        :type: oci.data_connectivity.models.RegistryMetadata
        """
        self._registry_metadata = registry_metadata

    @property
    def metadata(self):
        """
        Gets the metadata of this ReferenceArtifactSummary.

        :return: The metadata of this ReferenceArtifactSummary.
        :rtype: oci.data_connectivity.models.ObjectMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this ReferenceArtifactSummary.

        :param metadata: The metadata of this ReferenceArtifactSummary.
        :type: oci.data_connectivity.models.ObjectMetadata
        """
        self._metadata = metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .certificate_authority_rule import CertificateAuthorityRule
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CertificateAuthorityIssuanceExpiryRule(CertificateAuthorityRule):
    """
    A rule that enforces how long certificates or certificate authorities (CAs) issued by this particular CA are valid.
    You must include either or both `leafCertificateMaxValidityDuration` and `certificateAuthorityMaxValidityDuration`.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CertificateAuthorityIssuanceExpiryRule object with values from keyword arguments. The default value of the :py:attr:`~oci.certificates_management.models.CertificateAuthorityIssuanceExpiryRule.rule_type` attribute
        of this class is ``CERTIFICATE_AUTHORITY_ISSUANCE_EXPIRY_RULE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param rule_type:
            The value to assign to the rule_type property of this CertificateAuthorityIssuanceExpiryRule.
            Allowed values for this property are: "CERTIFICATE_AUTHORITY_ISSUANCE_EXPIRY_RULE"
        :type rule_type: str

        :param leaf_certificate_max_validity_duration:
            The value to assign to the leaf_certificate_max_validity_duration property of this CertificateAuthorityIssuanceExpiryRule.
        :type leaf_certificate_max_validity_duration: str

        :param certificate_authority_max_validity_duration:
            The value to assign to the certificate_authority_max_validity_duration property of this CertificateAuthorityIssuanceExpiryRule.
        :type certificate_authority_max_validity_duration: str

        """
        self.swagger_types = {
            'rule_type': 'str',
            'leaf_certificate_max_validity_duration': 'str',
            'certificate_authority_max_validity_duration': 'str'
        }

        self.attribute_map = {
            'rule_type': 'ruleType',
            'leaf_certificate_max_validity_duration': 'leafCertificateMaxValidityDuration',
            'certificate_authority_max_validity_duration': 'certificateAuthorityMaxValidityDuration'
        }

        self._rule_type = None
        self._leaf_certificate_max_validity_duration = None
        self._certificate_authority_max_validity_duration = None
        self._rule_type = 'CERTIFICATE_AUTHORITY_ISSUANCE_EXPIRY_RULE'

    @property
    def leaf_certificate_max_validity_duration(self):
        """
        Gets the leaf_certificate_max_validity_duration of this CertificateAuthorityIssuanceExpiryRule.
        A property indicating the maximum validity duration, in days, of leaf certificates issued by this CA.
        Expressed in `ISO 8601`__ format.

        __ https://en.wikipedia.org/wiki/ISO_8601#Time_intervals


        :return: The leaf_certificate_max_validity_duration of this CertificateAuthorityIssuanceExpiryRule.
        :rtype: str
        """
        return self._leaf_certificate_max_validity_duration

    @leaf_certificate_max_validity_duration.setter
    def leaf_certificate_max_validity_duration(self, leaf_certificate_max_validity_duration):
        """
        Sets the leaf_certificate_max_validity_duration of this CertificateAuthorityIssuanceExpiryRule.
        A property indicating the maximum validity duration, in days, of leaf certificates issued by this CA.
        Expressed in `ISO 8601`__ format.

        __ https://en.wikipedia.org/wiki/ISO_8601#Time_intervals


        :param leaf_certificate_max_validity_duration: The leaf_certificate_max_validity_duration of this CertificateAuthorityIssuanceExpiryRule.
        :type: str
        """
        self._leaf_certificate_max_validity_duration = leaf_certificate_max_validity_duration

    @property
    def certificate_authority_max_validity_duration(self):
        """
        Gets the certificate_authority_max_validity_duration of this CertificateAuthorityIssuanceExpiryRule.
        A property indicating the maximum validity duration, in days, of subordinate CA's issued by this CA.
        Expressed in `ISO 8601`__ format.

        __ https://en.wikipedia.org/wiki/ISO_8601#Time_intervals


        :return: The certificate_authority_max_validity_duration of this CertificateAuthorityIssuanceExpiryRule.
        :rtype: str
        """
        return self._certificate_authority_max_validity_duration

    @certificate_authority_max_validity_duration.setter
    def certificate_authority_max_validity_duration(self, certificate_authority_max_validity_duration):
        """
        Sets the certificate_authority_max_validity_duration of this CertificateAuthorityIssuanceExpiryRule.
        A property indicating the maximum validity duration, in days, of subordinate CA's issued by this CA.
        Expressed in `ISO 8601`__ format.

        __ https://en.wikipedia.org/wiki/ISO_8601#Time_intervals


        :param certificate_authority_max_validity_duration: The certificate_authority_max_validity_duration of this CertificateAuthorityIssuanceExpiryRule.
        :type: str
        """
        self._certificate_authority_max_validity_duration = certificate_authority_max_validity_duration

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MacroPivotField(object):
    """
    MacroPivotField is used for the PivotField with macro expressions. It can contain the rules according to the macro pattern/attribute added and create new fields according to the PivotKeyValues
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MacroPivotField object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_use_source_type:
            The value to assign to the is_use_source_type property of this MacroPivotField.
        :type is_use_source_type: bool

        :param expr:
            The value to assign to the expr property of this MacroPivotField.
        :type expr: oci.data_integration.models.Expression

        :param use_type:
            The value to assign to the use_type property of this MacroPivotField.
        :type use_type: oci.data_integration.models.ConfiguredType

        :param type:
            The value to assign to the type property of this MacroPivotField.
        :type type: oci.data_integration.models.BaseType

        :param column_name_pattern:
            The value to assign to the column_name_pattern property of this MacroPivotField.
        :type column_name_pattern: str

        """
        self.swagger_types = {
            'is_use_source_type': 'bool',
            'expr': 'Expression',
            'use_type': 'ConfiguredType',
            'type': 'BaseType',
            'column_name_pattern': 'str'
        }

        self.attribute_map = {
            'is_use_source_type': 'isUseSourceType',
            'expr': 'expr',
            'use_type': 'useType',
            'type': 'type',
            'column_name_pattern': 'columnNamePattern'
        }

        self._is_use_source_type = None
        self._expr = None
        self._use_type = None
        self._type = None
        self._column_name_pattern = None

    @property
    def is_use_source_type(self):
        """
        Gets the is_use_source_type of this MacroPivotField.
        Specifies whether the type of macro fields is inferred from an expression or useType (false) or the source field (true).


        :return: The is_use_source_type of this MacroPivotField.
        :rtype: bool
        """
        return self._is_use_source_type

    @is_use_source_type.setter
    def is_use_source_type(self, is_use_source_type):
        """
        Sets the is_use_source_type of this MacroPivotField.
        Specifies whether the type of macro fields is inferred from an expression or useType (false) or the source field (true).


        :param is_use_source_type: The is_use_source_type of this MacroPivotField.
        :type: bool
        """
        self._is_use_source_type = is_use_source_type

    @property
    def expr(self):
        """
        Gets the expr of this MacroPivotField.

        :return: The expr of this MacroPivotField.
        :rtype: oci.data_integration.models.Expression
        """
        return self._expr

    @expr.setter
    def expr(self, expr):
        """
        Sets the expr of this MacroPivotField.

        :param expr: The expr of this MacroPivotField.
        :type: oci.data_integration.models.Expression
        """
        self._expr = expr

    @property
    def use_type(self):
        """
        Gets the use_type of this MacroPivotField.

        :return: The use_type of this MacroPivotField.
        :rtype: oci.data_integration.models.ConfiguredType
        """
        return self._use_type

    @use_type.setter
    def use_type(self, use_type):
        """
        Sets the use_type of this MacroPivotField.

        :param use_type: The use_type of this MacroPivotField.
        :type: oci.data_integration.models.ConfiguredType
        """
        self._use_type = use_type

    @property
    def type(self):
        """
        Gets the type of this MacroPivotField.

        :return: The type of this MacroPivotField.
        :rtype: oci.data_integration.models.BaseType
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this MacroPivotField.

        :param type: The type of this MacroPivotField.
        :type: oci.data_integration.models.BaseType
        """
        self._type = type

    @property
    def column_name_pattern(self):
        """
        Gets the column_name_pattern of this MacroPivotField.
        column name pattern can be used to generate the name structure of the generated columns. By default column names are of %PIVOT_KEY_VALUE% or %MACRO_INPUT%_%PIVOT_KEY_VALUE%, but we can change it something by passing something like MY_PREFIX%PIVOT_KEY_VALUE%MY_SUFFIX or MY_PREFIX%MACRO_INPUT%_%PIVOT_KEY_VALUE%MY_SUFFIX which will add custom prefix and suffix to the column name.


        :return: The column_name_pattern of this MacroPivotField.
        :rtype: str
        """
        return self._column_name_pattern

    @column_name_pattern.setter
    def column_name_pattern(self, column_name_pattern):
        """
        Sets the column_name_pattern of this MacroPivotField.
        column name pattern can be used to generate the name structure of the generated columns. By default column names are of %PIVOT_KEY_VALUE% or %MACRO_INPUT%_%PIVOT_KEY_VALUE%, but we can change it something by passing something like MY_PREFIX%PIVOT_KEY_VALUE%MY_SUFFIX or MY_PREFIX%MACRO_INPUT%_%PIVOT_KEY_VALUE%MY_SUFFIX which will add custom prefix and suffix to the column name.


        :param column_name_pattern: The column_name_pattern of this MacroPivotField.
        :type: str
        """
        self._column_name_pattern = column_name_pattern

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
